@@ -5,7 +5,7 @@ use warnings;
 
 use if $] >= 5.019, 'deprecate';
 
-our $VERSION='4.35_01';
+our $VERSION='4.05';
 
 use CGI::Util qw(rearrange unescape escape);
 use overload '""' => \&as_string, 'cmp' => \&compare, 'fallback' => 1;
@@ -106,13 +106,13 @@ sub new {
   # Ignore mod_perl request object--compatibility with Apache::Cookie.
   shift if ref $params[0]
         && eval { $params[0]->isa('Apache::Request::Req') || $params[0]->isa('Apache') };
-  my ( $name, $value, $path, $domain, $secure, $expires, $max_age, $httponly, $samesite )
+  my ( $name, $value, $path, $domain, $secure, $expires, $max_age, $httponly )
    = rearrange(
     [
       'NAME', [ 'VALUE', 'VALUES' ],
       'PATH',   'DOMAIN',
       'SECURE', 'EXPIRES',
-      'MAX-AGE','HTTPONLY','SAMESITE'
+      'MAX-AGE','HTTPONLY'
     ],
     @params
    );
@@ -128,7 +128,6 @@ sub new {
   $self->expires( $expires )   if defined $expires;
   $self->max_age( $max_age )   if defined $max_age;
   $self->httponly( $httponly ) if defined $httponly;
-  $self->samesite( $samesite ) if defined $samesite;
   return $self;
 }
 
@@ -142,13 +141,12 @@ sub as_string {
     my $value = join "&", map { escape($_) } $self->value;
     my @cookie = ( "$name=$value" );
 
-    push @cookie,"domain=".$self->domain     if $self->domain;
-    push @cookie,"path=".$self->path         if $self->path;
-    push @cookie,"expires=".$self->expires   if $self->expires;
-    push @cookie,"max-age=".$self->max_age   if $self->max_age;
-    push @cookie,"secure"                    if $self->secure;
-    push @cookie,"HttpOnly"                  if $self->httponly;
-    push @cookie,"SameSite=".$self->samesite if $self->samesite;
+    push @cookie,"domain=".$self->domain   if $self->domain;
+    push @cookie,"path=".$self->path       if $self->path;
+    push @cookie,"expires=".$self->expires if $self->expires;
+    push @cookie,"max-age=".$self->max_age if $self->max_age;
+    push @cookie,"secure"                  if $self->secure;
+    push @cookie,"HttpOnly"                if $self->httponly;
 
     return join "; ", @cookie;
 }
@@ -224,20 +222,13 @@ sub path {
     return $self->{'path'};
 }
 
+
 sub httponly { # HttpOnly
     my ( $self, $httponly ) = @_;
     $self->{'httponly'} = $httponly if defined $httponly;
     return $self->{'httponly'};
 }
 
-my %_legal_samesite = ( Strict => 1, Lax => 1 );
-sub samesite { # SameSite
-    my $self = shift;
-    my $samesite = ucfirst lc +shift if @_; # Normalize casing.
-    $self->{'samesite'} = $samesite if $samesite and $_legal_samesite{$samesite};
-    return $self->{'samesite'};
-}
-
 1;
 
 =head1 NAME
@@ -337,14 +328,6 @@ See these URLs for more information:
     http://msdn.microsoft.com/en-us/library/ms533046.aspx
     http://www.browserscope.org/?category=security&v=top
 
-=item B<6. samesite flag>
-
-Allowed settings are C<Strict> and C<Lax>.
-
-As of June 2016, support is limited to recent releases of Chrome and Opera.
-
-L<https://tools.ietf.org/html/draft-west-first-party-cookies-07>
-
 =back
 
 =head2 Creating New Cookies
@@ -355,8 +338,7 @@ L<https://tools.ietf.org/html/draft-west-first-party-cookies-07>
                            '-max-age' =>  '+3M',
                              -domain  =>  '.capricorn.com',
                              -path    =>  '/cgi-bin/database',
-                             -secure  =>  1,
-                             -samesite=>  "Lax"
+                             -secure  =>  1
 	                    );
 
 Create cookies from scratch with the B<new> method.  The B<-name> and
@@ -392,9 +374,6 @@ cookie only when a cryptographic protocol is in use.
 B<-httponly> if set to a true value, the cookie will not be accessible
 via JavaScript.
 
-B<-samesite> may be C<Lax> or C<Strict> and is an evolving part of the
-standards for cookies. Please refer to current documentation regarding it.
-
 For compatibility with Apache::Cookie, you may optionally pass in
 a mod_perl request object as the first argument to C<new()>. It will
 simply be ignored:
